#ifndef NT2_INCLUDE_CONSTANTS_LOG_2OLOG_10_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_LOG_2OLOG_10_HPP_INCLUDED

#include <nt2/exponential/include/constants/log_2olog_10.hpp>

#endif
